@@ -7,11 +7,13 @@ from __future__ import print_function, division, absolute_import
 Module that base classes used by the callback system
 """
 
+import logging
 from traceback import format_exc
 
-import tpDcc
 from tpDcc.libs.python import decorators
 
+LOGGER = logging.getLogger('tpDcc-core')
+
 
 class ICallback(object):
     """
@@ -70,9 +72,9 @@ class AbstractCallback(object):
             self._shutdown_notifier = shutdown_notifier
             self._shutdown_token = self._shutdown_notifier.register(self._shutdown)
 
-    def __del__(self):
-        if self._notifier:
-            self._shutdown([])
+    # def __del__(self):
+    #     if self._notifier:
+    #         self._shutdown([])
 
     def _connect(self, fn):
         """
@@ -266,15 +268,15 @@ class SimpleCallback(AbstractCallback):
         Forces an unregistering from the notifier
         """
 
-        tpDcc.logger.debug('Started: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Started: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
         for entry in self._registry:
-            tpDcc.logger.debug(
+            LOGGER.debug(
                 '{}._shutdown - Disconnecting ({})'.format(str(self._notifier), self.__class__.__name__, str(entry)))
             entry.token = self._disconnect(entry.token)
         del self._registry[:]
 
         super(self.__class__, self)._shutdown(*args)
-        tpDcc.logger.debug('Complete: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Complete: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
 
     @property
     def empty(self):
@@ -313,7 +315,7 @@ class SimpleCallback(AbstractCallback):
                 entry.callback()
             except Exception:
                 from traceback import format_exc
-                tpDcc.logger.error(format_exc())
+                LOGGER.error(format_exc())
 
     @enabled.setter
     def enabled(self, value):
@@ -338,15 +340,15 @@ class SimpleCallback(AbstractCallback):
         """
 
         entry = next((e for e in self._registry if e.callback == fn), None)
-        tpDcc.logger.debug(
+        LOGGER.debug(
             'Started: ({}) {} Register - fn:"{}", owner:"{}", entry:"{}"'.format(
                 str(self._notifier), self.__class__.__name__, str(fn), owner, str(entry)))
         if not entry:
             token = self._connect(fn) if self.connected else None
-            tpDcc.logger.debug(
+            LOGGER.debug(
                 '({}) {} Register - token:"{}"'.format(str(self._notifier), self.__class__.__name__, str(token)))
             self._registry.append(SimpleCallback.RegistryEntry(fn, token, owner=owner))
-        tpDcc.logger.debug('Completed: ({}) {} Register'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Completed: ({}) {} Register'.format(str(self._notifier), self.__class__.__name__))
 
     def unregister(self, fn):
         """
@@ -355,13 +357,13 @@ class SimpleCallback(AbstractCallback):
         """
 
         entry = next((e for e in self._registry if e.callback == fn), None)
-        tpDcc.logger.debug(
+        LOGGER.debug(
             'Started: ({}) {} Unregister - fn:"{}", entry:"{}"'.format(
                 str(self._notifier), self.__class__.__name__, str(fn), str(entry)))
         if entry:
             self._disconnect(entry.token)
             self._registry.remove(entry)
-        tpDcc.logger.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
 
     def unregister_owner_callbacks(self, owner):
         """
@@ -370,18 +372,18 @@ class SimpleCallback(AbstractCallback):
         """
 
         entry = next((e for e in self._registry if e.owner == owner), None)
-        tpDcc.logger.debug(
+        LOGGER.debug(
             'Started: ({}) {} Unregister - owner:"{}", entry:"{}"'.format(
                 str(self._notifier), self.__class__.__name__, str(owner), str(entry)))
         if entry:
             self._disconnect(entry.token)
             self._registry.remove(entry)
-        tpDcc.logger.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
 
 
 class FilterCallback(AbstractCallback, object):
     """
-    Provides a implementatino of an Abstractcallback interface that allows the filtering of the callback
+    Provides a implementation of an Abstractcallback interface that allows the filtering of the callback
     generated from the notifier. It maintains a many-to-one relationship between listeners and notifier
     """
 
@@ -400,14 +402,14 @@ class FilterCallback(AbstractCallback, object):
         Forces an unregistering from the notifier
         """
 
-        tpDcc.logger.debug('Started: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Started: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
         if self._token:
             self._token = self._disconnect(self._token)
             self._token = None
         del self._registry[:]
 
         super(self.__class__, self)._shutdown(*args)
-        tpDcc.logger.debug('Complete: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Complete: ({}) {} Shutdown'.format(str(self._notifier), self.__class__.__name__))
 
     def _notify(self, *args):
         """
@@ -432,7 +434,7 @@ class FilterCallback(AbstractCallback, object):
             try:
                 entry.callback(*args)
             except Exception:
-                tpDcc.logger.error(format_exc())
+                LOGGER.error(format_exc())
 
     @property
     def empty(self):
@@ -482,15 +484,15 @@ class FilterCallback(AbstractCallback, object):
         @param owner: class, owner of the callback
         """
 
-        tpDcc.logger.debug(
+        LOGGER.debug(
             'Started: ({}) {} Register - fn:"{}", owner:"{}", IsEmpty:"{}"'.format(
                 str(self._notifier), self.__class__.__name__, str(fn), owner, bool(self.empty)))
         if self.empty:
             self._token = self._connect(self._notify)
-            tpDcc.logger.debug(
+            LOGGER.debug(
                 '({}) {} Register - token:"{}"'.format(str(self._notifier), self.__class__.__name__, str(self._token)))
         self._registry.append(FilterCallback.RegistryEntry(fn, owner=owner))
-        tpDcc.logger.debug('Completed: ({}) {} Register'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Completed: ({}) {} Register'.format(str(self._notifier), self.__class__.__name__))
 
     def unregister(self, fn):
         """
@@ -499,7 +501,7 @@ class FilterCallback(AbstractCallback, object):
         """
 
         entry = next((e for e in self._registry if e.callback == fn), None)
-        tpDcc.logger.debug(
+        LOGGER.debug(
             'Started: ({}) {} Unregister - fn:"{}", IsEmpty:"{}"'.format(
                 str(self._notifier), self.__class__.__name__, str(fn), bool(self.empty)))
 
@@ -510,10 +512,10 @@ class FilterCallback(AbstractCallback, object):
         #     str(self._notifier), self.__class__.__name__, str(fn)))
 
         if self.empty and self.connected:
-            tpDcc.logger.debug(
+            LOGGER.debug(
                 '({}) {} Unregister token:"{}"'.format(str(self._notifier), self.__class__.__name__, str(self._token)))
             self._token = self._disconnect(self._token)
-        tpDcc.logger.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
 
     def unregister_owner_callbacks(self, owner):
         """
@@ -522,7 +524,7 @@ class FilterCallback(AbstractCallback, object):
         """
 
         entry = next((e for e in self._registry if e.owner == owner), None)
-        tpDcc.logger.debug(
+        LOGGER.debug(
             'Started: ({}) {} Unregister - owner:"{}", entry:"{}"'.format(
                 str(self._notifier), self.__class__.__name__, str(owner), str(entry)))
         if entry:
@@ -532,10 +534,10 @@ class FilterCallback(AbstractCallback, object):
         #     str(self._notifier), self.__class__.__name__, str(owner)))
 
         if self.empty and self.connected:
-            tpDcc.logger.debug(
+            LOGGER.debug(
                 '({}) {} Unregister token:"{}"'.format(str(self._notifier), self.__class__.__name__, str(self._token)))
             self._token = self._disconnect(self._token)
-        tpDcc.logger.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
+        LOGGER.debug('Completed: ({}) {} Unregister'.format(str(self._notifier), self.__class__.__name__))
 
 
 class CallbackInstance(object):
@@ -557,15 +559,15 @@ class CallbackInstance(object):
         if self._callback:
             self._callback.register(self._notify)
 
-    def __del__(self):
-        """
-        Destructor
-        """
-
-        if self._callback:
-            self._callback.unregister(self._notify)
-        self._callback = None
-        self._notify = None
+    # def __del__(self):
+    #     """
+    #     Destructor
+    #     """
+    #
+    #     if self._callback:
+    #         self._callback.unregister(self._notify)
+    #     self._callback = None
+    #     self._notify = None
 
     @property
     def callback(self):
@@ -594,7 +596,7 @@ class PythonTickCallback(ICallback, object):
 
         fn_id = id(fn)
         if cls.tick_threads.get(fn_id, None) is not None:
-            tpDcc.logger.warning('{} already registered with PythonTickNotifier'.format(str(fn)))
+            LOGGER.warning('{} already registered with PythonTickNotifier'.format(str(fn)))
             return None
 
         repeater = cls._tick(fn_id)
